@@ -71,7 +71,7 @@ class DBLogManager(models.Manager):
                 )
         except Exception:
             exc_info = sys.exc_info()
-            logger.exception(exc_info[1], exc_info=exc_info)
+            logger.exception(exc_info[1])
         else:
             return instance
     
@@ -119,8 +119,9 @@ class DBLogManager(models.Manager):
 
         def to_unicode(f):
             if isinstance(f, dict):
+                nf = dict()
                 for k, v in f.iteritems():
-                    f[k] = to_unicode(v)
+                    nf[k] = to_unicode(v)
             elif isinstance(f, (list, tuple)):
                 f = [to_unicode(f) for f in f]
             else:
