@@ -8,7 +8,9 @@ from django.utils.encoding import smart_unicode
 from djangodblog.models import Error, ErrorBatch
 from djangodblog.middleware import DBLogMiddleware
 from djangodblog.utils import JSONDictField
+
 import logging
+import sys
 
 class RequestFactory(Client):
     # Used to generate request objects.
@@ -55,14 +57,15 @@ class DBLogTestCase(TestCase):
         Error.objects.all().delete()
         ErrorBatch.objects.all().delete()
 
+        dblog_handler = DBLogHandler()
 
         logger = logging.getLogger()
-        logger.setLevel(logging.DEBUG)
         for h in logger.handlers:
             # TODO: fix this, for now, I don't care.
             logger.removeHandler(h)
 
-        logger.addHandler(DBLogHandler())
+        logger.setLevel(logging.DEBUG)
+        logger.addHandler(dblog_handler)
 
         logger.error('This is a test error')
         cur = (Error.objects.count(), ErrorBatch.objects.count())
@@ -96,6 +99,26 @@ class DBLogTestCase(TestCase):
         self.assertEquals(last.logger, 'test')
         self.assertEquals(last.level, logging.INFO)
         self.assertEquals(last.message, 'This is a test info')
+        
+        logger.info('This is a test info with a url', extra=dict(url='http://example.com'))
+        cur = (Error.objects.count(), ErrorBatch.objects.count())
+        self.assertEquals(cur, (5, 4), 'Assumed logs failed to save. %s' % (cur,))
+        last = Error.objects.all().order_by('-id')[0:1].get()
+        self.assertEquals(last.url, 'http://example.com')
+        
+        try:
+            raise ValueError('This is a test ValueError')
+        except ValueError:
+            logger.info('This is a test info with an exception', exc_info=sys.exc_info())
+            cur = (Error.objects.count(), ErrorBatch.objects.count())
+            self.assertEquals(cur, (6, 5), 'Assumed logs failed to save. %s' % (cur,))
+            last = Error.objects.all().order_by('-id')[0:1].get()
+            self.assertEquals(last.class_name, 'ValueError')
+            self.assertEquals(last.message, 'This is a test info with an exception')
+            self.assertTrue(last.data.get('exc'))
+            
+        logger = logging.getLogger()
+        logger.removeHandler(dblog_handler)
     
     def testMiddleware(self):
         Error.objects.all().delete()
@@ -128,9 +151,18 @@ class DBLogTestCase(TestCase):
             Error.objects.create_from_exception(exc)
         else:
             self.fail('Unable to create `Error` entry.')
+
+        try:
+            Error.objects.get(id=999999989)
+        except Error.DoesNotExist, exc:
+            error = Error.objects.create_from_exception()
+            self.assertTrue(error.data.get('exc'))
+        else:
+            self.fail('Unable to create `Error` entry.')
+
         
         cur = (Error.objects.count(), ErrorBatch.objects.count())
-        self.assertEquals(cur, (1, 1), 'Assumed logs failed to save. %s' % (cur,))
+        self.assertEquals(cur, (2, 2), 'Assumed logs failed to save. %s' % (cur,))
         last = Error.objects.all().order_by('-id')[0:1].get()
         self.assertEquals(last.logger, 'root')
         self.assertEquals(last.class_name, 'DoesNotExist')
@@ -140,7 +172,7 @@ class DBLogTestCase(TestCase):
         Error.objects.create_from_text('This is an error', level=logging.DEBUG)
         
         cur = (Error.objects.count(), ErrorBatch.objects.count())
-        self.assertEquals(cur, (2, 2), 'Assumed logs failed to save. %s' % (cur,))
+        self.assertEquals(cur, (3, 3), 'Assumed logs failed to save. %s' % (cur,))
         last = Error.objects.all().order_by('-id')[0:1].get()
         self.assertEquals(last.logger, 'root')
         self.assertEquals(last.level, logging.DEBUG)
